==> haskell-iproute-1.7.11-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 iproute
version:              1.7.11
visibility:           public
id:                   iproute-1.7.11-DLPiKG7ZPhYAdkg8ccQ3w3
key:                  iproute-1.7.11-DLPiKG7ZPhYAdkg8ccQ3w3
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  ee8ff8efa0a55882815be507ccd549ff
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.0.1/site-local/iproute-1.7.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/iproute-1.7.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/iproute-1.7.11
hs-libraries:         HSiproute-1.7.11-DLPiKG7ZPhYAdkg8ccQ3w3
depends:
    appar-0.1.8-6ipk2j5YhiZFAmGSKCnDbn base-4.15.0.0
    byteorder-1.0.4-ElHejAMhLVsLg9LTW3whJ9 bytestring-0.10.12.1
    containers-0.6.4.1 network-3.1.2.2-9BU8QqWnKeP98A8KvbSili

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.11-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 iproute
version:              1.7.11
visibility:           public
id:                   iproute-1.7.11-F27VP43fQER6qAmg0EFZzp
key:                  iproute-1.7.11-F27VP43fQER6qAmg0EFZzp
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  8f7b66a4487e390e7e732040c8a2480a
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.0.1/site-local/iproute-1.7.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/iproute-1.7.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/iproute-1.7.11
hs-libraries:         HSiproute-1.7.11-F27VP43fQER6qAmg0EFZzp
depends:
    appar-0.1.8-6ipk2j5YhiZFAmGSKCnDbn base-4.15.0.0
    byteorder-1.0.4-ElHejAMhLVsLg9LTW3whJ9 bytestring-0.10.12.1
    containers-0.6.4.1 network-3.1.2.2-HXcjy5szECnDN1PS9jNchP

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
